// src/utils/authAsyncLocalStorage.ts
import { AsyncLocalStorage } from "node:async_hooks";
var authAsyncLocalStorage = new AsyncLocalStorage();

// src/utils/generateVisitorTokens.ts
import { OAuthStrategy } from "@wix/sdk";
import { WIX_CLIENT_ID } from "astro:env/client";
var auth = OAuthStrategy({
  clientId: WIX_CLIENT_ID
});
async function generateVisitorTokens() {
  return auth.generateVisitorTokens();
}

// src/utils/getSessionTokensFromCookie.ts
import { TokenRole } from "@wix/sdk";
import { WIX_CLIENT_ID as WIX_CLIENT_ID2 } from "astro:env/client";
import { z } from "astro/zod";
var tokensSchema = z.object({
  clientId: z.string(),
  tokens: z.object({
    accessToken: z.object({
      expiresAt: z.number(),
      value: z.string()
    }),
    refreshToken: z.object({
      role: z.nativeEnum(TokenRole),
      value: z.string()
    })
  })
});
function getSessionTokensFromCookie(context) {
  if (!context.isPrerendered) {
    const rawCookie = context.cookies.get("wixSession")?.json();
    if (rawCookie) {
      const tokensParseResult = tokensSchema.safeParse(rawCookie);
      if (tokensParseResult.success && tokensParseResult.data.clientId === WIX_CLIENT_ID2) {
        return tokensParseResult.data;
      }
    }
  }
  return null;
}

// src/utils/saveSessionTokensToCookie.ts
import { WIX_CLIENT_ID as WIX_CLIENT_ID3 } from "astro:env/client";
function sessionCookieJson(tokens) {
  return {
    clientId: WIX_CLIENT_ID3,
    tokens
  };
}
function saveSessionTokensToCookie(context, tokens) {
  context.cookies.set("wixSession", sessionCookieJson(tokens), {
    path: "/",
    secure: true
  });
}

// src/middleware/auth.ts
var onRequest = async (context, next) => {
  const store = {
    sessionTokens: getSessionTokensFromCookie(context)
  };
  const response = await authAsyncLocalStorage.run(store, () => {
    return next();
  });
  if (!context.isPrerendered && store.sessionTokens == null) {
    saveSessionTokensToCookie(context, await generateVisitorTokens());
  }
  return response;
};
export {
  onRequest
};
