import type { MiddlewareHandler } from 'astro';
import { authAsyncLocalStorage } from '../utils/authAsyncLocalStorage.js';
import { generateVisitorTokens } from '../utils/generateVisitorTokens.js';
import { getSessionTokensFromCookie } from '../utils/getSessionTokensFromCookie.js';
import { saveSessionTokensToCookie } from '../utils/saveSessionTokensToCookie.js';

export const onRequest: MiddlewareHandler = async (context, next) => {
  const store = {
    sessionTokens: getSessionTokensFromCookie(context),
  };

  const response = await authAsyncLocalStorage.run(store, () => {
    return next();
  });

  if (!context.isPrerendered && store.sessionTokens == null) {
    saveSessionTokensToCookie(context, await generateVisitorTokens());
  }

  return response;
};
