import { extname, join } from 'node:path';
import type { PluginOption } from 'vite';
import { outdent } from 'outdent';
import { SRC_DIR } from '../directories.js';

export function setupSsrContext(rootDir: string): PluginOption {
  const srcDir = join(rootDir, SRC_DIR);

  const nonElevatedSetupUrl = new URL(
    '../build-runtime/context/non-elevated.js',
    import.meta.url
  );
  const elevatedSetupUrl = new URL(
    '../build-runtime/context/elevated.js',
    import.meta.url
  );

  return {
    applyToEnvironment(environment) {
      return environment.name === 'ssr';
    },
    name: 'setup-ssr-context',
    transform(code, id) {
      if (!id.startsWith(srcDir)) {
        return null;
      }

      const extension = extname(id);

      if (
        extension !== '.js' &&
        extension !== '.astro' &&
        extension !== '.ts' &&
        extension !== '.tsx'
      ) {
        return null;
      }

      return outdent`
        import '${nonElevatedSetupUrl}';
        import '${elevatedSetupUrl}';

        ${code}
      `;
    },
  };
}
