import type { APIContext } from 'astro';
import { TokenRole } from '@wix/sdk';
import { WIX_CLIENT_ID } from 'astro:env/client';
import { z } from 'astro/zod';

const tokensSchema = z.object({
  clientId: z.string(),
  tokens: z.object({
    accessToken: z.object({
      expiresAt: z.number(),
      value: z.string(),
    }),
    refreshToken: z.object({
      role: z.nativeEnum(TokenRole),
      value: z.string(),
    }),
  }),
});

export type SessionTokens = z.infer<typeof tokensSchema>;

export function getSessionTokensFromCookie(
  context: APIContext
): null | SessionTokens {
  if (!context.isPrerendered) {
    const rawCookie = context.cookies.get('wixSession')?.json();

    if (rawCookie) {
      const tokensParseResult = tokensSchema.safeParse(rawCookie);

      if (
        tokensParseResult.success &&
        tokensParseResult.data.clientId === WIX_CLIENT_ID
      ) {
        return tokensParseResult.data;
      }
    }
  }

  return null;
}
